%% ci_tecrep.cls V1.0, Frank-Michael Schleif <schleif@informatik.uni-leipzig.de>
%%                                  http://www.uni-leipzig.de/~compint
%%
%%  Copyright (C) 2007 Frank-Michael Schleif
%%
%%  This program is free software; you can redistribute it and/or modify
%%  it under the terms of the GNU General Public License as published by
%%  the Free Software Foundation; either version 2 of the License, or
%%  (at your option) any later version.
%%
%%  This program is distributed in the hope that it will be useful,
%%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%%  GNU General Public License for more details.
%% 
%%  You should have received a copy of the GNU General Public License
%%  along with this program; if not, write to the Free Software
%%  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ci_tecrep}[2007/20/08 F.-M.Schleif]
\typeout{ci_tecrep.cls V1.0 Frank-Michael Schleif}
\RequirePackage{ifthen}
\newif\if@german
\newif\if@restonecol
\@germantrue
\RequirePackage[latin1]{inputenc}
\RequirePackage[OT1]{fontenc}
\DeclareOption{german}{\@germantrue}
\DeclareOption{english}{\@germanfalse}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[a4paper, 12pt, twoside]{article}
\if@german
  \RequirePackage{german}
  \setlength{\parindent}{0pt}
  \def\@bibstyle{alphadin}
\else
  \def\@bibstyle{alpha}
\fi
\RequirePackage{latexsym, amssymb, verbatim, graphicx, 
chapterbib, calc, rotating, mflogo, picins, url, amsmath, 
subfigure, plain, listings, dsfont, units, psfrag, eurosym}
\RequirePackage{colortbl, color, watermark,multirow}
\definecolor{lightgray}{gray}{0.88}
\definecolor{dkblue}{cmyk}{1,1,0,0.3}
\definecolor{dkred}{cmyk}{0,1,1,0.3}
\definecolor{ciblue}{cmyk}{0.85,0.75,0,0}      % normal blue
\definecolor{ltciblue}{cmyk}{0.27,0.05,0,0}    % light blue
\definecolor{ciyellow}{cmyk}{0.1,0.0,0.93,0.0} % yellow
\definecolor{ciorange}{cmyk}{0.0,0.8,0.94,0.0} % orange
\definecolor{ciblue}{rgb}{0.13,0.20,0.96}       
\definecolor{ltciblue}{rgb}{0.76,0.88,0.99}
\definecolor{ciyellow}{rgb}{1.0,1.0,0.0}     % yellow
\definecolor{ciorange}{rgb}{1.0,0.3,0.0}     % orange


%% DVI-PS/PDF Weiche
%\newif\ifpdf
%\ifx\pdfoutput\undefined
%  \pdffalse
%\else
%  \pdftrue
%\fi
%\ifpdf
% \pdfoutput=1
% \RequirePackage[pdftex=true,hyperindex=true,bookmarks=true,bookmarksnumbered=true,colorlinks=true,linkcolor=dkblue,citecolor=dkblue]{hyperref}
%\else
%  \RequirePackage[hyperindex=true]{hyperref}
%\fi


\usepackage{ifpdf}
\ifpdf
  \usepackage[pdftex,    
  a4paper,            %verwendetes Papierformat
  colorlinks=true,    %Bei false macht er einen häßlcihen roten Rahmen um die Links
  linkcolor=blue,    %Linkfarbe im PDF schwarz machen. Für elektronische Version ändern.
  citecolor=blue,    %Linkfarbe im PDF schwarz machen. Für elektronische Version ändern.
  urlcolor=blue,
  bookmarks=true,     %Inhaltsverzeichnis auf der linken Seite beim öffnen der PDF
  bookmarksopen=true,     %Das Verzeichnis öffnen
  bookmarksopenlevel=2,   %Öffnungstiefe (chapter, section, subsection)
  %pagebackref=false,      %Aus Literaturverzeichnissen etc. auf die entsprechende Seite springen
  bookmarksnumbered=true, %Einträge im Verzeichnis nummerieren
  pdfstartpage=1,         %Startseite für die Anzeige festlegen
  pdfpagemode=UseOutlines
  ]{hyperref}
\fi
                  

%% Definition des \subtitle{}-Befehls und Vorbelegung mit einem Leerzeichen
\def\@subtitle{\ }
\def\subtitle#1{\def\@subtitle{#1}}

\def\@authoraddresse{\ }
\def\authoraddresse#1{\def\@authoraddresse{#1}}

\def\@subpub{\ }
\def\subpub#1{\def\@subpub{#1}}


%% Sichern und Umdefinieren \bibliographystyle{}-Befehls 
\let\bibliostyle\bibliographystyle
\renewcommand\bibliographystyle[1]{\def\@bibstyle{#1}}

%% Einstellung der Schriftart Helvetica und Formatierung der Abschnittsbefehle
\renewcommand{\familydefault}{phv}
\renewcommand\section{\@startsection{section}{1}{\z@}%
                                   {-3.5ex \@plus -1ex \@minus -.2ex}%
                                   {2.3ex \@plus.2ex}%
                                   {\normalfont\Large\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                   {-3.25ex \@plus -1ex \@minus -.2ex}%
                                   {1.5ex \@plus .2ex}%
                                   {\normalfont\large\bfseries}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                   {-3.25ex \@plus -1ex \@minus -.2ex}%
                                   {1.5ex \@plus .2ex}%
                                   {\normalfont\normalsize\bfseries}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                   {-3.25ex \@plus -1ex \@minus -.2ex}%
                                   {0.5ex}%
                                   {\normalfont\normalsize\itshape}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\z@}%
                                   {-3.25ex \@plus -1ex \@minus -.2ex}%
                                   {0.5ex}%
                                   {\normalfont\normalsize\itshape}}

%% Nummerierung der Abschnitte bis zur vierten Ebene (Paragraph)
\setcounter{secnumdepth}{4}                                    

%% Definition der Reports
\if@german
	\newcommand{\MLR}{Machine Learning Reports}
\else
	\newcommand{\MLR}{Machine Learning Reports}
\fi

%% Definition der AG
\if@german
	\newcommand{\AG}{Arbeitsgruppe Computational Intelligence}
\else
	\newcommand{\AG}{Research group on Computational Intelligence}
\fi
%% Definition der AG Adresse
\if@german
	\newcommand{\Adresse}{University of Applied Sciences Mittweida\\Technikumplatz 17, 09648 Mittweida, Germany \\ $\bullet$ http://www.mni.hs-mittweida.de/}
	\newcommand{\SAdresse}{University of Bielefeld\\Universit\"atsstrasse 21-23, 33615 Bielefeld, Germany, \\ $\bullet$ http://www.cit-ec.de/tcs/about }
	\newcommand{\WebAdresse}{http://www.techfak.uni-bielefeld.de/$\sim$fschleif/mlr/mlr.html}	
	\newcommand{\journalname}{Machine Learning Reports}	
\else
	\newcommand{\Adresse}{University of Applied Sciences Mittweida\\Technikumplatz 17, 09648 Mittweida, Germany \\ $\bullet$ http://www.mni.hs-mittweida.de/}
	\newcommand{\SAdresse}{University of Bielefeld\\Universit\"atsstrasse 21-23, 33615 Bielefeld, Germany\\  $\bullet$ http://www.cit-ec.de/tcs/about }
	\newcommand{\WebAdresse}{http://www.techfak.uni-bielefeld.de/$\sim$fschleif/mlr/mlr.html}	
	\newcommand{\journalname}{Machine Learning Reports}	
\fi

%\font\ftitle=phvr scaled 1500

%% Einstellungen der Papiermae des Layouts
%\setlength{\paperwidth}{210mm}
%\setlength{\paperheight}{297mm}
\setlength{\voffset}{-1pt}
\setlength{\topmargin}{-20mm}
\setlength{\headheight}{12.5mm}
\setlength{\headsep}{8mm}
\setlength{\textheight}{245mm}
\setlength{\textwidth}{160mm}
\setlength{\hoffset}{-1pt}
\setlength{\evensidemargin}{0mm}
\setlength{\oddsidemargin}{0mm}
\setlength{\footskip}{13.5mm}
\setlength{\marginparwidth}{20mm}
\setlength{\marginparsep}{2mm}

%% Einstellung der Kopf- und Fuzeilen
\newcommand{\ps@ciheadings}{\let\@mkboth\markboth
  \renewcommand{\sectionmark}[1]{}
	\renewcommand{\subsectionmark}[1]{}
	\renewcommand{\@oddfoot}{\ifthenelse{\equal{\thepage}{1}}{\begin{minipage}{\textwidth}\hrule\ \\[-24pt]{\small\begin{center}\MLR\\ \WebAdresse\end{center}}\end{minipage}}{\begin{minipage}{\textwidth}\hrule\ \\[-2pt]{\small\MLR\hfill\thepage}\end{minipage}}}
	\renewcommand{\@evenfoot}{\begin{minipage}{\textwidth}\hrule\ \\[-2pt]{\small\thepage\hfill\MLR}\end{minipage}}
	\renewcommand{\@oddhead}{\ifthenelse{\equal{\thepage}{1}}{}{\begin{minipage}{\textwidth}\hrule\ \\[-42pt]{\small\begin{center}\@title\end{center}}\end{minipage}}}
	\renewcommand{\@evenhead}{\@oddhead}
}
\pagestyle{ciheadings}

%% Erzeugt die Indexumgebung mit Kopf- und -Fuzeile
\renewenvironment{theindex}
               {\if@twocolumn
                  \@restonecolfalse
                \else
                  \@restonecoltrue
                \fi
                \columnseprule \z@
                \columnsep 35\p@
								%\if@twocolumn \section*{\indexname} \else 
								\twocolumn \section*{\indexname}
								%\fi
                \@mkboth{\MakeUppercase\indexname}%
                        {\MakeUppercase\indexname}%
                \thispagestyle{ciheadings}\parindent\z@
                \parskip\z@ \@plus .3\p@\relax
                \let\item\@idxitem}%
              {	\if@restonecol
              		%\onecolumn % keine Ahnung, warum diese Zeile Fehler macht... :-(
                \else
                	%\clearpage % keine Ahnung, warum diese Zeile Fehler macht... :-(
                \fi }

\newcommand*\see[2]{\emph{\seename} #1}
\providecommand*\seealso[2]{\emph{\alsoname} #1}
\newcommand\printindex{\@input@{\jobname.ind}}
\providecommand\seename{siehe}
\providecommand*\alsoname{siehe auch}


%% Erzeugt den "Briefkopf" fr die Titelseite und die Eintrge fr der PDF-Dateieigenschaften
%% Verwendet die Subroutine \@maketitle
\if@titlepage
  \renewcommand\maketitle{
	\newlength{\wasserversatz}
	\setlength{\wasserversatz}{0.25\textwidth}
	\addtolength{\wasserversatz}{\headheight}
  \begin{titlepage}
 		\thiswatermark{\parbox[t]{\textwidth}{\vspace{.6\wasserversatz}\includegraphics[width=\textwidth]{cilogo_blur}}}
		\@maketitle{}{60mm}{{\Huge\bf\title}\\[15mm]{\Large\bf\subtitle}\\[60mm]{\large\@date}\\{\large\@subpub}\\[5mm]{\@author\\*[10mm]\@authoraddresse}}
  \end{titlepage}
  \setcounter{footnote}{0}%
}
\else
\renewcommand{\maketitle}{
	\if@twocolumn
  	\ifnum \col@number=\@ne
      \@maketitle{{\bf \subtitle}\\*[2mm]}{7mm}{\Large\bf\title}
    \else
      \twocolumn[\@maketitle{{\bf \subtitle}\\*[2mm]}{7mm}{\Large\bf\title}\vspace{12mm}]%  	
    \fi
	\else
		\@maketitle{{\bf \subtitle}\\*[2mm]}{7mm}{\Large\bf\title}
	\fi
}
\fi
%% Subroutine fr die "Briefkopf"-Erzeugung
\def\@maketitle#1#2#3{%
  \renewcommand{\title}{\@title}
  \renewcommand{\subtitle}{\@subtitle}
  \renewcommand{\author}{\begin{tabular}{l}\@author\end{tabular}}
  %% Falls PDF werden die Dateieigenschaften gesetzt
	\ifpdf
  	\pdfinfo
			{ /Title (\title)
				%/Creator (LaTeX)
				%/Producer (pdfTeX 1.10b)
				/Author (\@author)
				%/CreationDate (D:19980212201000)
				%/ModDate (D:19980212201000)
				/Subject (\subtitle)
				%/Keywords (mouse,cat) 
			}
	\fi
  \noindent  
  \parbox{165mm}{
  	\begin{center}
  		#1
	  	\tabcolsep0mm
	  	\bf\sc\huge\journalname
	  \end{center}
	}\nolinebreak
  \\[#2]
  \begin{center}
  	#3
  \end{center}
}
%% Definiert die titlepage-Umgebung fr die Titelseite
\renewenvironment{titlepage}
    {%
      \if@twocolumn
        \@restonecoltrue\onecolumn
      \else
        \@restonecolfalse\newpage
      \fi
      \thispagestyle{ciheadings}%       	
      \setcounter{page}\@ne
    }%
    {\if@restonecol\twocolumn \else \newpage \fi
     \if@twoside\else
        \setcounter{page}\@ne
     \fi
    }

%% \bsp fgt den Text Beispiel: an der entsprechenden Stelle mit
%% Formatierung ein.
\newcommand{\bsp}{\textbf{Beispiel:\ }}

%% \begr stellt das erste Argument formatiert dar und fgt das
%% zweite dem Index hinzu. Wichtig bei Pluralformen.
\newcommand{\begr}[2]{\textit{#1}\index{#2}}

%% \begriff stellt das Argument formatiert dar und fgt es dem
%% Index hinzu.
\newcommand{\begriff}[1]{\begr{#1}{#1}}

%% \tm erzeugt ein hochgestelltes TM (Trademark-Zeichen)
\newcommand{\TM}{\raisebox{1ex}{\footnotesize TM}}

%% \kreis stellt das Argument (das nicht lnger als zwei Zeichen sein sollte)
%% in einem Kreis dar.
\newcommand{\kreis}[1]{\setlength{\unitlength}{1ex}
	\begin{picture}(2.2,2.2)
	\put(0.75,0.75){\circle{2.8}}
	\put(-0.25,0){\makebox[2ex][c]{#1}}
	\end{picture}}

%% \notiz stellt das Argument im Randbereich der Seite dar, hilfreich fr 
%% Gedankensttzen und Notizen, die bis zur finalen Version noch
%% eingearbeitet werden sollen.
\newcommand{\notiz}[1]{\marginpar{{\textit{\tiny{#1}}}}}

%% \abb gibt den Text Abbildung bzw. Figure und die Nummer der per label 
%% referenzierten Abbildung aus, damit diese nicht getrennt werden, wird
%% die ganze Ausgabe von einer mbox umschlossen.
\if@german
  \newcommand{\abb}[1]{\mbox{Abbildung \ref{#1}}}
\else
  \newcommand{\abb}[1]{\mbox{Figure \ref{#1}}}
\fi

%% Stellt das Argument von \code formatiert dar. Geeignet fr kurze 
%% Programmbeispiele und -fragmente
\newcommand{\code}[1]{{\texttt{#1}}}

%% Stellt die Umgebung codeenv zur Verfgung, in der Programmcode entsprechend
%% formatiert dargestellt werden kann. Besonders geeignet fr lngere
%% Sourcecode Auszge.
\begingroup
\lccode`\~=`\'
\lowercase{\endgroup
\newenvironment{codeenv}{%
  \trivlist
  \scriptsize
  \item\relax
    \leftskip\@totalleftmargin
    \rightskip\z@skip
    \parindent\z@
    \parfillskip\@flushglue
    \parskip\z@skip
    \@@par
    \@tempswafalse
    \def\par{%
      \if@tempswa
        \leavevmode\null\@@par\penalty\interlinepenalty
      \else
      	\@tempswatrue
      	\ifhmode\@@par\penalty\interlinepenalty\fi
    	\fi}
    \obeylines
    \verbatim@font
    \let\org@prime~%
    \@noligs
    \everymath\expandafter{\the\everymath
      \catcode`\'=12 \let~\org@prime}
    \everydisplay\expandafter{\the\everydisplay
      \catcode`\'=12 \let~\org@prime}
    \let\org@dospecials\dospecials
    \g@remfrom@specials{\\}
    \g@remfrom@specials{\{}
    \g@remfrom@specials{\}}
    \let\do\@makeother
    \dospecials
    \let\dospecials\org@dospecials
    \frenchspacing\@vobeyspaces
    \everypar \expandafter{\the\everypar \unpenalty}}
{\endtrivlist}
}
\def\g@remfrom@specials#1{%
  \def\@new@specials{}
  \def\@remove##1{%
    \ifx##1#1\else
    \g@addto@macro\@new@specials{\do ##1}\fi}
  \let\do\@remove\dospecials
  \let\dospecials\@new@specials
  }


%% Definition der Spaltentypen L (linksbndig, fett) und K (blauer Hintergrund, weie Schrift, zentriert, fett)
\newcolumntype{L}{>{\bfseries}l}
\newcolumntype{K}{>{\color{white}\columncolor{ciblue}\bfseries}c}

\newif\if@geradezeile
\newcommand{\cinewline}{
	\if@geradezeile
		\global\@geradezeilefalse
	\else
		\global\@geradezeiletrue
	\fi
	\\[4pt]\hline
	\if@geradezeile
		\rowcolor{ltciblue} 
	\else
		\rowcolor{ciyellow}
	\fi
}

\newenvironment{citabular}[1]
{
 	\arrayrulecolor{white}
	\arrayrulewidth1pt
	\tabcolsep9pt
	\extrarowheight6pt
	\@geradezeiletrue
  \begin{tabular}{#1}
		\rowcolor{ciblue}
}
{
	\end{tabular}
}


%% Erzeugt eine Impressumsseite
%% Verwendet die Subroutine \@makeimpressum
\newcommand\makeimpressum{
	\setlength{\wasserversatz}{0.25\textwidth}
	\addtolength{\wasserversatz}{\headheight}
  \begin{titlepage}
 		\thiswatermark{\parbox[t]{\textwidth}{\vspace{\wasserversatz}\centering\includegraphics[width=0.7\textwidth]{cilogo_blur}}}
		\@maketitle{}{10mm}{{\large\@date}\\*[105mm]} 
		\framebox[165mm]{
			\begin{minipage}[c]{160mm}
					\begin{tabular}{cccc}												
						\multicolumn{4}{c}{\bf \large Impressum}\\
						\multicolumn{2}{l}{Machine Learning Reports} & &
						ISSN: 1865-3960 \\
						\rowcolor{ciyellow}
						{$\bigtriangledown$}&\multicolumn{3}{l}{\colorbox{ciyellow}{Publisher/Editors}}\\
						                    &\multicolumn{3}{l}{\multirow{8}{20cm}{Prof. Dr. rer. nat. Thomas Villmann \\ \Adresse \\[0.5cm]  Dr. rer. nat. Frank-Michael Schleif \\ \SAdresse \\}}\\
						                    & \\
						                    & \\
			                    
						                    & \\
			                    
						                    
						                    & \\
									                    
						                    & \\
									                    
						                    & \\
									                    
						                    & \\
									                    
						                    & \\
									                    						                    
						\rowcolor{ciyellow}
						{$\bigtriangledown$}&\multicolumn{3}{l}{\colorbox{ciyellow}{Copyright \& Licence}}\\
						       		    &\multicolumn{3}{l}{\multirow{1}{15cm}{Copyright of the articles remains to the authors.}}\\
						\rowcolor{ciyellow}
						{$\bigtriangledown$}&\multicolumn{3}{l}{\colorbox{ciyellow}{Acknowledgments}}\\
							          &\multicolumn{3}{l}{We would like to thank the reviewers for their time and patience.}
					\end{tabular}
			\end{minipage}			
		}
  \end{titlepage}
  \setcounter{footnote}{0}%
}
%% Definiert die titlepage-Umgebung fr die Titelseite
\renewenvironment{titlepage}
    {%
      \if@twocolumn
        \@restonecoltrue\onecolumn
      \else
        \@restonecolfalse\newpage
      \fi
      \thispagestyle{ciheadings}%       	
      \setcounter{page}\@ne
    }%
    {\if@restonecol\twocolumn \else \newpage \fi
     \if@twoside\else
        \setcounter{page}\@ne
     \fi
    }

\AtEndDocument
{
  \bibliostyle{\@bibstyle}
  \makeimpressum
}